@@ -1,4 +1,4 @@
-from ledger_system.client import LedgerClient
+from ledger.client import LedgerClient
 
 import logging
 
